@@ -1,11 +1,9 @@
-# $Id: Retail454.pm 24 2012-07-05 23:48:48Z jim $
-
 package DateTime::Fiscal::Retail454;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our $R454DEBUG = 0;
 
@@ -368,6 +366,12 @@ __END__
 
 DateTime::Fiscal::Retail454 - create 4-5-4 Calendar data from DateTime objects.
 
+=head1 DEPRECATED
+
+This module has been deprecated! Please use L<DateTimeX::Fiscal::Fiscal5253>
+instead. The new module has enhanced support for NRF 4-5-4 calenders as well
+as for 52/53 week fiscal years in general.
+
 =head1 SYNOPSIS
 
  use DateTime::Fiscal::Retail454;
@@ -601,11 +605,20 @@ Method(s) to return the R454 period or week_of_year for various holidays.
 
 =head1 SEE ALSO
 
-L<DateTime>
+=over
+
+=item L<DataTimeX::Fiscal::Fiscal5253>
+
+A replacement module for DateTime::Fiscal::Retail454 that has better methods,
+more functionality and does not sub-class DateTime. Please use it instead.
+
+=item L<DateTime>
 
 The Retail 4-5-4 Calendar as descibed by the National Retail Federation
 L<http://www.nrf.com/modules.php?name=Pages&sp_id=391>
 
+=back
+
 =head1 SUPPORT
 
 Support is provided by the author. Please report bugs or make feature
